==> homelawnsecurity-0.0.5.1-sources.jar: net/db64/homelawnsecurity/item/custom/LawnGadgetItem.java <==
package net.db64.homelawnsecurity.item.custom;

import net.db64.homelawnsecurity.block.custom.lawn.ILawnBlock;
import net.db64.homelawnsecurity.component.LawnGadgetComponent;
import net.db64.homelawnsecurity.component.ModDataComponentTypes;
import net.db64.homelawnsecurity.sound.ModSounds;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_5819;

public class LawnGadgetItem extends class_1792 {
	/*@Deprecated
	protected static final Map<Block, BlockState> STATES_TURF_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_PATH_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_PATH_TYPE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_MARKER_TURF_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_MARKER_PATH_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_MARKER_PATH_TYPE;*/

	public LawnGadgetItem(class_1793 settings) {
		super(settings);
	}

	@Override
	public boolean method_7885(class_1799 stack, class_2680 state, class_1937 world, class_2338 pos, class_1309 miner) {
		if (!world.field_9236) {
			class_5819 random = miner.method_59922();
			/*if (miner.isSneaking()) {
				toggleMarkerMode(miner.getStackInHand(Hand.MAIN_HAND), miner);
				world.playSound(null, miner.getBlockPos(), ModSounds.ITEM_LAWN_GADGET_SWITCH, SoundCategory.PLAYERS, 0.5f, (random.nextFloat() * 0.4f) + 1.6f);
			}*/
			//else {
				switchMode(miner.method_5998(class_1268.field_5808), miner);
				world.method_8396(null, miner.method_24515(), ModSounds.ITEM_LAWN_GADGET_SWITCH, class_3419.field_15248, 0.5f, (random.method_43057() * 0.4f) + 0.8f);
			//}
		}

		return false;
	}

	@Override
	public class_1269 method_7884(class_1838 context) {
		if (context.method_8045().field_9236) return class_1269.field_5812;

		class_1799 stack = context.method_8041();
		class_3218 world = (class_3218) context.method_8045();
		class_2338 pos = context.method_8037();

		LawnGadgetComponent component = stack.method_58694(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) {
			// If the component is null, set it to its default value
			//setComponentToDefault(stack);
			// Actually no, play a funny sound and return
			world.method_8396(null, pos, class_3417.field_15075.comp_349(), class_3419.field_15248, 0.5f, 1.0f);
			sendMessage(context.method_8036(), class_2561.method_43471(method_7876() + ".use.error"));
			return class_1269.field_21466;
		}

		class_2680 state = world.method_8320(pos);
		//Block block = state.getBlock();

		String mode = component.mode();
		// Which map should it use?
		/*Map<Block, BlockState> map = switch (mode) {
			case "turf_toggle" -> STATES_TURF_TOGGLE;
			case "path_toggle" -> STATES_PATH_TOGGLE;
			case "path_type" -> STATES_PATH_TYPE;
			case "turf_toggle_marker" -> STATES_MARKER_TURF_TOGGLE;
			case "path_toggle_marker" -> STATES_MARKER_PATH_TOGGLE;
			case "path_type_marker" -> STATES_MARKER_PATH_TYPE;
			default -> STATES_TURF_TOGGLE;
		};*/

		// Set the block state to the new one
		/*if (map.containsKey(block)) {
			world.setBlockState(pos, map.get(block));
			world.playSound(null, pos, world.getBlockState(pos).getSoundGroup().getPlaceSound(), SoundCategory.PLAYERS, 1.0f, 1.0f);
		}*/

		if (state.method_26204() instanceof ILawnBlock) {
			switch (mode) {
				case "path_type_main", "path_type_main_marker":
					ILawnBlock.setMainPathId(pos, world, ILawnBlock.getNextMainPathId(state));
					break;
				case "path_type_intersecting", "path_type_intersecting_marker":
					ILawnBlock.setIntersectingPathId(pos, world, ILawnBlock.getNextIntersectingPathId(state));
					break;
			}
			world.method_8396(null, pos, world.method_8320(pos).method_26231().method_10598(), class_3419.field_15248, 1.0f, 1.0f);
		}
		/*else {
			world.playSound(null, context.getPlayer().getBlockPos(), ModSounds.RANDOM_BUZZER, SoundCategory.PLAYERS, 1.0f, 1.0f);
		}*/

		return class_1269.field_21466;
	}

	public void switchMode(class_1799 stack, class_1309 entity) {
		LawnGadgetComponent component = stack.method_58694(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) { // Lawn gadget component is null for some reason, make it the default value
			setComponentToDefault(stack);
			if (entity instanceof class_1657 player)
				sendMessage(player, class_2561.method_43471(method_7876() + ".switch.error"));
		}
		else { // Component is not null, continue as normal
			String mode = component.mode();
			mode = switch (mode) { // case "currentMode": mode = "nextMode";
				/*case "turf_toggle" -> "path_toggle";
				case "path_toggle" -> "path_type";
				case "path_type" -> "turf_toggle";
				case "turf_toggle_marker" -> "path_toggle_marker";
				case "path_toggle_marker" -> "path_type_marker";
				case "path_type_marker" -> "turf_toggle_marker";*/
				case "path_type_main" -> "path_type_intersecting";
				case "path_type_intersecting" -> "path_type_main";
				/*case "path_type_main_marker" -> "path_type_intersecting_marker";
				case "path_type_intersecting_marker" -> "path_type_main_marker";*/
				default -> "path_type_main";
			};
			stack.method_57379(ModDataComponentTypes.LAWN_GADGET, new LawnGadgetComponent(mode));
			if (entity instanceof class_1657 player)
				sendMessage(player,
					class_2561.method_43469(method_7876() + ".switch",
						class_2561.method_43471(method_7876() + ".mode." + mode)));
		}
	}

	/*public void toggleMarkerMode(ItemStack stack, LivingEntity entity) {
		LawnGadgetComponent component = stack.get(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) { // Lawn gadget component is null for some reason, make it the default value
			setComponentToDefault(stack);
			if (entity instanceof PlayerEntity player)
				sendMessage(player, Text.translatable(getTranslationKey() + ".switch.error"));
		}
		else { // Component is not null, continue as normal
			String mode = component.mode();
			mode = switch (mode) { // case "currentMode": mode = "nextMode";
				/case "turf_toggle" -> "turf_toggle_marker";
				case "turf_toggle_marker" -> "turf_toggle";
				case "path_toggle" -> "path_toggle_marker";
				case "path_toggle_marker" -> "path_toggle";
				case "path_type" -> "path_type_marker";
				case "path_type_marker" -> "path_type";/
				case "path_type_main" -> "path_type_main_marker";
				case "path_type_main_marker" -> "path_type_main";
				case "path_type_intersecting" -> "path_type_intersecting_marker";
				case "path_type_intersecting_marker" -> "path_type_intersecting";
				default -> "path_type_main";
			};
			stack.set(ModDataComponentTypes.LAWN_GADGET, new LawnGadgetComponent(mode));
			if (entity instanceof PlayerEntity player)
				sendMessage(player,
					Text.translatable(getTranslationKey() + ".switch",
						Text.translatable(getTranslationKey() + ".mode." + mode)));
		}
	}*/

	public void setComponentToDefault(class_1799 stack) {
		stack.method_57379(ModDataComponentTypes.LAWN_GADGET, new LawnGadgetComponent("path_type_main"));
	}

	private static void sendMessage(class_1657 player, class_2561 message) {
		((class_3222) player).method_43502(message, true);
	}

	/*public static boolean shouldRevealMarkers(ItemStack stack) {
		LawnGadgetComponent component = stack.get(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) { // Lawn gadget component is null for some reason
			return false;
		}
		else { // Component is not null, continue as normal
			return component.mode().endsWith("_marker");
		}
	}*/

	/*static {
		// Blocks

		STATES_TURF_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_BLOCK, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.UNSODDED_LAWN_BLOCK, ModBlocks.LAWN_BLOCK.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_1, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_1, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_2, ModBlocks.ZOMBIE_PATH_BLOCK_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_2, ModBlocks.FERTILE_PATH_BLOCK_2.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_CROSS, ModBlocks.ZOMBIE_PATH_BLOCK_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_CROSS, ModBlocks.FERTILE_PATH_BLOCK_CROSS.getDefaultState())

			.build();

		STATES_PATH_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_BLOCK, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_1, ModBlocks.LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_2, ModBlocks.LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_CROSS, ModBlocks.LAWN_BLOCK.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_BLOCK, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_1, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_2, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_CROSS, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())

			.build();

		STATES_PATH_TYPE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_BLOCK, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_1, ModBlocks.FERTILE_PATH_BLOCK_2.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_2, ModBlocks.FERTILE_PATH_BLOCK_CROSS.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_CROSS, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_BLOCK, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.ZOMBIE_PATH_BLOCK_1, ModBlocks.ZOMBIE_PATH_BLOCK_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_2, ModBlocks.ZOMBIE_PATH_BLOCK_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_CROSS, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())

			.build();

		// Markers

		STATES_MARKER_TURF_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_MARKER, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())
			.put(ModBlocks.UNSODDED_LAWN_MARKER, ModBlocks.LAWN_MARKER.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_1, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_1, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_2, ModBlocks.ZOMBIE_PATH_MARKER_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_2, ModBlocks.FERTILE_PATH_MARKER_2.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_CROSS, ModBlocks.ZOMBIE_PATH_MARKER_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_CROSS, ModBlocks.FERTILE_PATH_MARKER_CROSS.getDefaultState())

			.build();

		STATES_MARKER_PATH_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_MARKER, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_1, ModBlocks.LAWN_MARKER.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_2, ModBlocks.LAWN_MARKER.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_CROSS, ModBlocks.LAWN_MARKER.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_MARKER, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_1, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_2, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_CROSS, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())

			.build();

		STATES_MARKER_PATH_TYPE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_MARKER, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_1, ModBlocks.FERTILE_PATH_MARKER_2.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_2, ModBlocks.FERTILE_PATH_MARKER_CROSS.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_CROSS, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_MARKER, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.ZOMBIE_PATH_MARKER_1, ModBlocks.ZOMBIE_PATH_MARKER_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_2, ModBlocks.ZOMBIE_PATH_MARKER_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_CROSS, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())

			.build();
	}*/
}

==> homelawnsecurity-0.0.5.2-sources.jar: net/db64/homelawnsecurity/item/custom/LawnGadgetItem.java <==
package net.db64.homelawnsecurity.item.custom;

import net.db64.homelawnsecurity.block.custom.lawn.ILawnBlock;
import net.db64.homelawnsecurity.component.LawnGadgetComponent;
import net.db64.homelawnsecurity.component.ModDataComponentTypes;
import net.db64.homelawnsecurity.sound.ModSounds;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_5819;

public class LawnGadgetItem extends class_1792 {
	/*@Deprecated
	protected static final Map<Block, BlockState> STATES_TURF_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_PATH_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_PATH_TYPE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_MARKER_TURF_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_MARKER_PATH_TOGGLE;
	@Deprecated
	protected static final Map<Block, BlockState> STATES_MARKER_PATH_TYPE;*/

	public LawnGadgetItem(class_1793 settings) {
		super(settings);
	}

	@Override
	public boolean method_7885(class_1799 stack, class_2680 state, class_1937 world, class_2338 pos, class_1309 miner) {
		if (!world.method_8608()) {
			class_5819 random = miner.method_59922();
			/*if (miner.isSneaking()) {
				toggleMarkerMode(miner.getStackInHand(Hand.MAIN_HAND), miner);
				world.playSound(null, miner.getBlockPos(), ModSounds.ITEM_LAWN_GADGET_SWITCH, SoundCategory.PLAYERS, 0.5f, (random.nextFloat() * 0.4f) + 1.6f);
			}*/
			//else {
				switchMode(miner.method_5998(class_1268.field_5808), miner);
				world.method_8396(null, miner.method_24515(), ModSounds.ITEM_LAWN_GADGET_SWITCH, class_3419.field_15248, 0.5f, (random.method_43057() * 0.4f) + 0.8f);
			//}
		}

		return false;
	}

	@Override
	public class_1269 method_7884(class_1838 context) {
		if (context.method_8045().method_8608()) return class_1269.field_5812;

		class_1799 stack = context.method_8041();
		class_3218 world = (class_3218) context.method_8045();
		class_2338 pos = context.method_8037();

		LawnGadgetComponent component = stack.method_58694(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) {
			// If the component is null, set it to its default value
			//setComponentToDefault(stack);
			// Actually no, play a funny sound and return
			world.method_8396(null, pos, class_3417.field_15075.comp_349(), class_3419.field_15248, 0.5f, 1.0f);
			sendMessage(context.method_8036(), class_2561.method_43471(method_7876() + ".use.error"));
			return class_1269.field_21466;
		}

		class_2680 state = world.method_8320(pos);
		//Block block = state.getBlock();

		String mode = component.mode();
		// Which map should it use?
		/*Map<Block, BlockState> map = switch (mode) {
			case "turf_toggle" -> STATES_TURF_TOGGLE;
			case "path_toggle" -> STATES_PATH_TOGGLE;
			case "path_type" -> STATES_PATH_TYPE;
			case "turf_toggle_marker" -> STATES_MARKER_TURF_TOGGLE;
			case "path_toggle_marker" -> STATES_MARKER_PATH_TOGGLE;
			case "path_type_marker" -> STATES_MARKER_PATH_TYPE;
			default -> STATES_TURF_TOGGLE;
		};*/

		// Set the block state to the new one
		/*if (map.containsKey(block)) {
			world.setBlockState(pos, map.get(block));
			world.playSound(null, pos, world.getBlockState(pos).getSoundGroup().getPlaceSound(), SoundCategory.PLAYERS, 1.0f, 1.0f);
		}*/

		if (state.method_26204() instanceof ILawnBlock) {
			switch (mode) {
				case "path_type_main", "path_type_main_marker":
					ILawnBlock.setMainPathId(pos, world, ILawnBlock.getNextMainPathId(state));
					break;
				case "path_type_intersecting", "path_type_intersecting_marker":
					ILawnBlock.setIntersectingPathId(pos, world, ILawnBlock.getNextIntersectingPathId(state));
					break;
			}
			world.method_8396(null, pos, world.method_8320(pos).method_26231().method_10598(), class_3419.field_15248, 1.0f, 1.0f);
		}
		/*else {
			world.playSound(null, context.getPlayer().getBlockPos(), ModSounds.RANDOM_BUZZER, SoundCategory.PLAYERS, 1.0f, 1.0f);
		}*/

		return class_1269.field_21466;
	}

	public void switchMode(class_1799 stack, class_1309 entity) {
		LawnGadgetComponent component = stack.method_58694(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) { // Lawn gadget component is null for some reason, make it the default value
			setComponentToDefault(stack);
			if (entity instanceof class_1657 player)
				sendMessage(player, class_2561.method_43471(method_7876() + ".switch.error"));
		}
		else { // Component is not null, continue as normal
			String mode = component.mode();
			mode = switch (mode) { // case "currentMode": mode = "nextMode";
				/*case "turf_toggle" -> "path_toggle";
				case "path_toggle" -> "path_type";
				case "path_type" -> "turf_toggle";
				case "turf_toggle_marker" -> "path_toggle_marker";
				case "path_toggle_marker" -> "path_type_marker";
				case "path_type_marker" -> "turf_toggle_marker";*/
				case "path_type_main" -> "path_type_intersecting";
				case "path_type_intersecting" -> "path_type_main";
				/*case "path_type_main_marker" -> "path_type_intersecting_marker";
				case "path_type_intersecting_marker" -> "path_type_main_marker";*/
				default -> "path_type_main";
			};
			stack.method_57379(ModDataComponentTypes.LAWN_GADGET, new LawnGadgetComponent(mode));
			if (entity instanceof class_1657 player)
				sendMessage(player,
					class_2561.method_43469(method_7876() + ".switch",
						class_2561.method_43471(method_7876() + ".mode." + mode)));
		}
	}

	/*public void toggleMarkerMode(ItemStack stack, LivingEntity entity) {
		LawnGadgetComponent component = stack.get(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) { // Lawn gadget component is null for some reason, make it the default value
			setComponentToDefault(stack);
			if (entity instanceof PlayerEntity player)
				sendMessage(player, Text.translatable(getTranslationKey() + ".switch.error"));
		}
		else { // Component is not null, continue as normal
			String mode = component.mode();
			mode = switch (mode) { // case "currentMode": mode = "nextMode";
				/case "turf_toggle" -> "turf_toggle_marker";
				case "turf_toggle_marker" -> "turf_toggle";
				case "path_toggle" -> "path_toggle_marker";
				case "path_toggle_marker" -> "path_toggle";
				case "path_type" -> "path_type_marker";
				case "path_type_marker" -> "path_type";/
				case "path_type_main" -> "path_type_main_marker";
				case "path_type_main_marker" -> "path_type_main";
				case "path_type_intersecting" -> "path_type_intersecting_marker";
				case "path_type_intersecting_marker" -> "path_type_intersecting";
				default -> "path_type_main";
			};
			stack.set(ModDataComponentTypes.LAWN_GADGET, new LawnGadgetComponent(mode));
			if (entity instanceof PlayerEntity player)
				sendMessage(player,
					Text.translatable(getTranslationKey() + ".switch",
						Text.translatable(getTranslationKey() + ".mode." + mode)));
		}
	}*/

	public void setComponentToDefault(class_1799 stack) {
		stack.method_57379(ModDataComponentTypes.LAWN_GADGET, new LawnGadgetComponent("path_type_main"));
	}

	private static void sendMessage(class_1657 player, class_2561 message) {
		((class_3222) player).method_43502(message, true);
	}

	/*public static boolean shouldRevealMarkers(ItemStack stack) {
		LawnGadgetComponent component = stack.get(ModDataComponentTypes.LAWN_GADGET);
		if (component == null) { // Lawn gadget component is null for some reason
			return false;
		}
		else { // Component is not null, continue as normal
			return component.mode().endsWith("_marker");
		}
	}*/

	/*static {
		// Blocks

		STATES_TURF_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_BLOCK, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.UNSODDED_LAWN_BLOCK, ModBlocks.LAWN_BLOCK.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_1, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_1, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_2, ModBlocks.ZOMBIE_PATH_BLOCK_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_2, ModBlocks.FERTILE_PATH_BLOCK_2.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_CROSS, ModBlocks.ZOMBIE_PATH_BLOCK_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_CROSS, ModBlocks.FERTILE_PATH_BLOCK_CROSS.getDefaultState())

			.build();

		STATES_PATH_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_BLOCK, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_1, ModBlocks.LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_2, ModBlocks.LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_CROSS, ModBlocks.LAWN_BLOCK.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_BLOCK, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_1, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_2, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_CROSS, ModBlocks.UNSODDED_LAWN_BLOCK.getDefaultState())

			.build();

		STATES_PATH_TYPE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_BLOCK, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_BLOCK_1, ModBlocks.FERTILE_PATH_BLOCK_2.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_2, ModBlocks.FERTILE_PATH_BLOCK_CROSS.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_BLOCK_CROSS, ModBlocks.FERTILE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_BLOCK, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())

			.put(ModBlocks.ZOMBIE_PATH_BLOCK_1, ModBlocks.ZOMBIE_PATH_BLOCK_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_2, ModBlocks.ZOMBIE_PATH_BLOCK_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_BLOCK_CROSS, ModBlocks.ZOMBIE_PATH_BLOCK_1.getDefaultState())

			.build();

		// Markers

		STATES_MARKER_TURF_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_MARKER, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())
			.put(ModBlocks.UNSODDED_LAWN_MARKER, ModBlocks.LAWN_MARKER.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_1, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_1, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_2, ModBlocks.ZOMBIE_PATH_MARKER_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_2, ModBlocks.FERTILE_PATH_MARKER_2.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_CROSS, ModBlocks.ZOMBIE_PATH_MARKER_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_CROSS, ModBlocks.FERTILE_PATH_MARKER_CROSS.getDefaultState())

			.build();

		STATES_MARKER_PATH_TOGGLE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_MARKER, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_1, ModBlocks.LAWN_MARKER.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_2, ModBlocks.LAWN_MARKER.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_CROSS, ModBlocks.LAWN_MARKER.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_MARKER, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_1, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_2, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_CROSS, ModBlocks.UNSODDED_LAWN_MARKER.getDefaultState())

			.build();

		STATES_MARKER_PATH_TYPE = new ImmutableMap.Builder<Block, BlockState>()

			.put(ModBlocks.LAWN_MARKER, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.FERTILE_PATH_MARKER_1, ModBlocks.FERTILE_PATH_MARKER_2.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_2, ModBlocks.FERTILE_PATH_MARKER_CROSS.getDefaultState())
			.put(ModBlocks.FERTILE_PATH_MARKER_CROSS, ModBlocks.FERTILE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.UNSODDED_LAWN_MARKER, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())

			.put(ModBlocks.ZOMBIE_PATH_MARKER_1, ModBlocks.ZOMBIE_PATH_MARKER_2.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_2, ModBlocks.ZOMBIE_PATH_MARKER_CROSS.getDefaultState())
			.put(ModBlocks.ZOMBIE_PATH_MARKER_CROSS, ModBlocks.ZOMBIE_PATH_MARKER_1.getDefaultState())

			.build();
	}*/
}
